Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(42)

Unified Diff: chromecast/media/cdm/cast_cdm_proxy.h

Issue 2568463003: media: Rename MediaKeys to ContentDecryptionModule (Closed)
Patch Set: comments addressed Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromecast/media/cdm/cast_cdm_factory.h ('k') | chromecast/media/cdm/cast_cdm_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromecast/media/cdm/cast_cdm_proxy.h
diff --git a/chromecast/media/cdm/cast_cdm_proxy.h b/chromecast/media/cdm/cast_cdm_proxy.h
index f17c4c199dab495884ce223d12444bcba7b87826..e11fd7d451ee9c1ffa597d36a368d7105458c385 100644
--- a/chromecast/media/cdm/cast_cdm_proxy.h
+++ b/chromecast/media/cdm/cast_cdm_proxy.h
@@ -9,6 +9,7 @@
#include "base/threading/thread_checker.h"
#include "chromecast/media/cdm/cast_cdm.h"
+#include "media/base/content_decryption_module.h"
namespace base {
class SingleThreadTaskRunner;
@@ -17,11 +18,11 @@ class SingleThreadTaskRunner;
namespace chromecast {
namespace media {
// MediaKeys implementation that lives on the UI thread and forwards all calls
// to a CastCdm instance on the CMA thread. This is used to simplify the
// UI-CMA threading interaction.
// TODO(slan): Remove this class when CMA is deprecated.
-class CastCdmProxy : public ::media::MediaKeys {
+class CastCdmProxy : public ::media::ContentDecryptionModule {
public:
CastCdmProxy(const scoped_refptr<CastCdm>& cast_cdm,
const scoped_refptr<base::SingleThreadTaskRunner>& task_runner);
@@ -32,17 +33,17 @@ class CastCdmProxy : public ::media::MediaKeys {
private:
~CastCdmProxy() override;
- // ::media::MediaKeys implementation:
+ // ::media::ContentDecryptionModule implementation:
void SetServerCertificate(
const std::vector<uint8_t>& certificate,
std::unique_ptr<::media::SimpleCdmPromise> promise) override;
void CreateSessionAndGenerateRequest(
- ::media::MediaKeys::SessionType session_type,
+ ::media::ContentDecryptionModule::SessionType session_type,
::media::EmeInitDataType init_data_type,
const std::vector<uint8_t>& init_data,
std::unique_ptr<::media::NewSessionCdmPromise> promise) override;
void LoadSession(
- ::media::MediaKeys::SessionType session_type,
+ ::media::ContentDecryptionModule::SessionType session_type,
const std::string& session_id,
std::unique_ptr<::media::NewSessionCdmPromise> promise) override;
void UpdateSession(
@@ -17,11 +18,11 @@ class SingleThreadTaskRunner;
namespace chromecast {
namespace media {
-// MediaKeys implementation that lives on the UI thread and forwards all calls
-// to a CastCdm instance on the CMA thread. This is used to simplify the
-// UI-CMA threading interaction.
+// ContentDecryptionModule implementation that lives on the UI thread and
+// forwards all calls to a CastCdm instance on the CMA thread. This is used to
+// simplify the UI-CMA threading interaction.
// TODO(slan): Remove this class when CMA is deprecated.
« no previous file with comments | « chromecast/media/cdm/cast_cdm_factory.h ('k') | chromecast/media/cdm/cast_cdm_proxy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698